==> jboss-test-1.0.0.GA-sources.jar: org/jboss/test/BaseTestCase.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test;

import org.jboss.logging.Logger;
import org.jboss.test.logging.LoggingPlugin;

/**
 * Base Test Case. Simple test support.
 * 
 * @author <a href="adrian@jboss.com">Adrian Brock</a>
 * @version $Revision: 37723 $
 */
public class BaseTestCase extends AbstractTestCase
{
   /** The logging plugin */
   protected LoggingPlugin logging;
   
   /** The log */
   protected Logger log;

   /**
    * Create a new base test case
    *
    * @param name the test name
    */
   public BaseTestCase(String name)
   {
      super(name);
   }

   public Logger getLog()
   {
      return log;
   }

   protected void setUp() throws Exception
   {
      logging = LoggingPlugin.getInstance();
      logging.setUp();
      configureLogging();
      log = Logger.getLogger(getClass());
      super.setUp();
   }
   
   protected void tearDown() throws Exception
   {
      super.tearDown();
   }

   protected void enableTrace(String name)
   {
      logging.enableTrace(name);
   }
}

==> jboss-test-1.1.9.GA-sources.jar: org/jboss/test/BaseTestCase.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test;

import junit.framework.Test;
import junit.framework.TestSuite;
import junit.framework.TestCase;
import org.jboss.logging.Logger;
import org.jboss.test.logging.LoggingPlugin;

/**
 * Base Test Case. Simple test support.
 * 
 * @author <a href="adrian@jboss.com">Adrian Brock</a>
 * @version $Revision: 62645 $
 */
public class BaseTestCase extends AbstractTestCase
{
   /** The logging plugin */
   protected LoggingPlugin logging;
   
   /** The log */
   protected Logger log;

   /**
    * Create a new base test case
    *
    * @param name the test name
    */
   public BaseTestCase(String name)
   {
      super(name);
   }

   /**
    * Create a new testsuite for the class
    *
    * @param clazz the class
    * @return the suite
    */
   public static Test suite(Class<? extends TestCase> clazz)
   {
      return new TestSuite(clazz);
   }

   public Logger getLog()
   {
      return log;
   }

   protected void setUp() throws Exception
   {
      logging = LoggingPlugin.getInstance();
      logging.setUp();
      configureLogging();
      log = Logger.getLogger(getClass());
      super.setUp();
   }
   
   protected void tearDown() throws Exception
   {
      super.tearDown();
   }

   protected void enableTrace(String name)
   {
      logging.enableTrace(name);
   }
}
